==> trove-1.0.2.tar.gz: trove-1.0.2/src/gnu/trove/ToObjectArrayProcedure.java <==
///////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2001, Eric D. Friedman All Rights Reserved.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
///////////////////////////////////////////////////////////////////////////////

package gnu.trove;

/**
 * A procedure which stores each value it receives into a target array.
 *
 * Created: Sat Jan 12 10:13:42 2002
 *
 * @author Eric D. Friedman
 * @version $Id: ToObjectArrayProcedure.java,v 1.1 2002/01/14 05:59:43 ericdf Exp $
 */

final class ToObjectArrayProcedure implements TObjectProcedure {
    private final Object[] target;
    private int pos = 0;
    
    public ToObjectArrayProcedure(final Object[] target) {
        this.target = target;
    }

    public final boolean execute(Object value) {
        target[pos++] = value;
        return true;
    }
} // ToObjectArrayProcedure

==> trove_2.1.0.orig.tar.gz: trove-2.1.0/src/gnu/trove/ToObjectArrayProcedure.java <==
///////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2001, Eric D. Friedman All Rights Reserved.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
///////////////////////////////////////////////////////////////////////////////

package gnu.trove;

/**
 * A procedure which stores each value it receives into a target array.
 *
 * Created: Sat Jan 12 10:13:42 2002
 *
 * @author Eric D. Friedman
 * @version $Id: ToObjectArrayProcedure.java,v 1.2 2006/11/10 23:27:57 robeden Exp $
 */

final class ToObjectArrayProcedure<T> implements TObjectProcedure<T> {
    private final T[] target;
    private int pos = 0;
    
    public ToObjectArrayProcedure(final T[] target) {
        this.target = target;
    }

    public final boolean execute(T value) {
        target[pos++] = value;
        return true;
    }
} // ToObjectArrayProcedure
